:tocdepth: 2

=================================
Block Storage API V2 (DEPRECATED)
=================================

.. rest_expand_all::

.. include:: api-versions.inc
.. include:: ext-backups.inc
.. include:: ext-backups-actions-v2.inc
.. include:: capabilities-v2.inc
.. include:: os-cgsnapshots-v2.inc
.. include:: consistencygroups-v2.inc
.. include:: hosts.inc
.. include:: limits.inc
.. include:: os-vol-pool-v2.inc
.. include:: os-vol-transfer-v2.inc
.. include:: qos-specs-v2-qos-specs.inc
.. include:: quota-classes.inc
.. include:: quota-sets.inc
.. include:: volume-manage.inc
.. include:: volume-type-access.inc
.. include:: volumes-v2-extensions.inc
.. include:: volumes-v2-snapshots.inc
.. include:: volumes-v2-snapshots-actions.inc
.. include:: volumes-v2-types.inc
.. include:: volumes-v2-versions.inc
.. include:: volumes-v2-volumes-actions.inc
.. include:: volumes-v2-volumes.inc
